
/********************************************************************************/
/*                        	* Frecuency-Counter code *                          */
/*                            By George A. Adamidis                             */
/*                            Ver 1.0 - March 17, 2009                          */ 
/********************************************************************************/
// All rights are reserved 


// Compiled using MPLAB-C18 V 8.10
// Loaded on a PIC18F2620 microcontroler
// All timing routines have been written for 4MHz master clock.
//--------------------------------------------------------------------------------

#include "Common.h"         /* General Definitions          */
#include <p18f2620.h>        /* pic18f242                    */
#include <p18cxxx.h>        /* TRISB and PORTB declarations */
#include <delays.h>         /* Delay purpose routines       */
#include <xlcd.h>           /* LCD purpose routines         */

/*functions declaration*/
void disst(void); 						// Displays current device state at LCD's second line, 
										//according to current channel, mode and function 
void DelayFor18TCY( void);				/* Delay of 18TCY - needed for xlcd.h routines*/	
void DelayPORXLCD (void);   			/* Delay of 18ms - needed for xlcd.h routines */ 
void DelayXLCD (void);					/* Delay of 7ms - needed for xlcd.h routines */	


// variables - declaration
extern char mode;
extern char units;
extern char function;

/**************************************************************************/
// Displays current device state at LCD's second line 
void disst(void)
{
while( BusyXLCD() );               		// waits until LCD not busy
SetDDRamAddr(0x40);                		// Sets LCDs cursor on first position on second line 

switch (mode)               			// mode=0,1,2--> normal, fast or slow counting mode respectively  
         {
           case 1:                               // Normal counting mode          
				while( BusyXLCD()) ;             // waits until LCD not busy
				putrsXLCD( "Normal-" );			 // Displays "Normal-" 		
	       break;
          
           case 0:                               // Fast counting mode      
				while( BusyXLCD()) ;             // waits until LCD not busy
				putrsXLCD( "Fast - " );			 // Displays "Fast-" 	     
           break;

		   case 2:                               // Slow counting mode - valid only for channel A        
				
				while( BusyXLCD()) ;     // waits until LCD not busy
				putrsXLCD( "Slow - " );	 // Displays "Slow-"
						   
           break;
        }

switch (function)                			// function=0 --> Realtime measuring, function=1 --> Max Hold measuring, function=2 --> Min Hold measuring 
         {
	         case 0:                              // Realtime measurement          
					while( BusyXLCD() );          // waits until LCD not busy
					putrsXLCD( "Real Time" );	  // Displays "Real Time" 		
	   		 break;
          
          	 case 1:                              // Max Hold measurement      
					while( BusyXLCD() );          // waits until LCD not busy
					putrsXLCD( "Max Hold " );	  // Displays "Max Hold" 	     
          	 break;
          
	   		case 2:                                // Min Hold measurement      
					while( BusyXLCD() );           // waits until LCD not busy
					putrsXLCD( "Min Hold " );	   // Displays "Min Hold" 	     
          	break;
		}

	
}


/**************************************************************************/
/* Delay of 18TCY - needed for xlcd.h routines*/
void DelayFor18TCY( void )
{
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
Nop();
return;
}


/**************************************************************************/
/* Delay of 18ms - needed for xlcd.h routines */
void DelayPORXLCD (void)
{
Delay1KTCYx(18); // Delay of 18ms
// Cycles = (TimeDelay * Fosc) / 4
// Cycles = (18ms * 4MHz) / 4
// Cycles = 18,000
return;
}


/**************************************************************************/
/* Delay of 7ms - needed for xlcd.h routines */
void DelayXLCD (void)
{
Delay1KTCYx(7); // Delay of 7ms
// Cycles = (TimeDelay * Fosc) / 4
// Cycles = (7ms * 4MHz) / 4
// Cycles = 7,000
Nop();
Nop();
return;
}

